@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Bos_setup
@@ -63,7 +62,8 @@ let targets =
 let parse_target, max_target_len =
   let add (acc, len) (t, v, _) = (t, v) :: acc, max len (String.length t) in
   let index, max = List.fold_left add ([], 0) targets in
-  fst (Cmdliner.Arg.enum index) (* This gives us trie lookup *) , max
+  (* This gives us trie lookup *)
+  Cmdliner.Arg.conv_parser (Cmdliner.Arg.enum index), max
 
 (* opam field uris *)
 
@@ -79,15 +79,15 @@ let opam_field_uri opam field =
 let browse () pkg_file opam browser prefix background target =
   begin
     let uri = match parse_target target with
-    | `Ok (`Uri uri) -> Ok uri
-    | `Ok (`Opam field) ->
+    | Ok (`Uri uri) -> Ok uri
+    | Ok (`Opam field) ->
         let pkg = Topkg_care.Pkg.v ?opam pkg_file in
         Topkg_care.Pkg.opam pkg >>= fun opam -> opam_field_uri opam field
-    | `Error msg ->
+    | Error msg ->
         let uri_prefixes = ["http://"; "https://"; "file://"] in
         if List.exists (fun p -> String.is_prefix ~affix:p target) uri_prefixes
         then Ok target
-        else Error (`Msg msg)
+        else Error msg
     in
     uri
     >>= fun uri -> Webbrowser.reload ~background ~prefix ?browser uri
@@ -121,23 +121,7 @@ let man =
     `Blocks (List.(tl @@ rev @@ fold_left target [] targets)); ]
 
 let cmd =
-  Term.(pure browse $ Cli.setup $ Cli.pkg_file $ Cli.opam $
+  Cmd.v (Cmd.info "browse" ~doc ~sdocs ~exits ~man ~man_xrefs) @@
+  Term.(const browse $ Cli.setup $ Cli.pkg_file $ Cli.opam $
         Webbrowser_cli.browser $ Webbrowser_cli.prefix $
-        Webbrowser_cli.background $ target),
-  Term.info "browse" ~doc ~sdocs ~exits ~man ~man_xrefs
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
+        Webbrowser_cli.background $ target)
