@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Bos_setup
@@ -104,10 +103,10 @@ let doc = "Create a package distribution archive"
 let sdocs = Manpage.s_common_options
 let exits = Cli.exits
 let envs =
-  [ Term.env_info "TOPKG_BZIP2" ~doc:"The $(b,bzip2) tool to use to compress the
+  [ Cmd.Env.info "TOPKG_BZIP2" ~doc:"The $(b,bzip2) tool to use to compress the
     archive. Gets the archive on stdin and must output the result on
     standard out.";
-    Term.env_info "TOPKG_TAR" ~doc:"The $(b,tar) tool to use to unarchive a tbz
+    Cmd.Env.info "TOPKG_TAR" ~doc:"The $(b,tar) tool to use to unarchive a tbz
     archive (archive creation itself is handled by topkg)."; ]
 
 let man_xrefs = [ `Main ]
@@ -159,23 +158,7 @@ let man =
          the future, for example to correct bugs."); ]
 
 let cmd =
-  Term.(pure distrib $ Cli.setup $ Cli.pkg_file $ Cli.dist_opam $
+  Cmd.v (Cmd.info "distrib" ~doc ~sdocs ~exits ~envs ~man ~man_xrefs) @@
+  Term.(const distrib $ Cli.setup $ Cli.pkg_file $ Cli.dist_opam $
         Cli.build_dir $ Cli.dist_name $ Cli.dist_version $ keep_build_dir $
-        skip_lint $ skip_build $ skip_tests),
-  Term.info "distrib" ~doc ~sdocs ~exits ~envs ~man ~man_xrefs
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
+        skip_lint $ skip_build $ skip_tests)
