@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Bos_setup
@@ -14,7 +13,7 @@ let get_issue_msg ~info = function
 | Some "" -> Ok None
 | Some msg -> Ok (Some (String.cuts ~sep:"\n" msg))
 | None ->
-    let is_msg s = not (String.is_prefix "#" s) in
+    let is_msg s = not (String.is_prefix ~affix:"#" s) in
     let rec rem_white_prefix = function
     | l :: ls when String.for_all Char.Ascii.is_white l -> rem_white_prefix ls
     | ls -> ls
@@ -116,8 +115,8 @@ let doc = "Interact with the package's issue tracker"
 let sdocs = Manpage.s_common_options
 let exits = Cli.exits
 let envs =
-  [ Term.env_info "EDITOR" ~doc:"The editor used to edit issue messages.";
-    Term.env_info "TOPKG_DELEGATE" ~doc:"The package delegate to use, see
+  [ Cmd.Env.info "EDITOR" ~doc:"The editor used to edit issue messages.";
+    Cmd.Env.info "TOPKG_DELEGATE" ~doc:"The package delegate to use, see
     topkg-delegate(7)." ]
 
 let man_xrefs = [ `Main ]
@@ -141,23 +140,6 @@ let man =
         "Close issue $(i,ID).") ]
 
 let cmd =
-  Term.(pure issue $ Cli.setup $ Cli.pkg_file $ Cli.opam $ Cli.delegate $
-        action $ id $ msg),
-  Term.info "issue" ~doc ~sdocs ~exits ~envs ~man ~man_xrefs
-
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
+  Cmd.v (Cmd.info "issue" ~doc ~sdocs ~exits ~envs ~man ~man_xrefs) @@
+  Term.(const issue $ Cli.setup $ Cli.pkg_file $ Cli.opam $ Cli.delegate $
+        action $ id $ msg)
