@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Bos_setup
@@ -77,9 +76,9 @@ let doc = "Show and edit the package's change log"
 let sdocs = Manpage.s_common_options
 let exits = Cli.exits
 let envs =
-  [ Term.env_info "EDITOR" ~doc:"The editor used to edit the change log.";
-    Term.env_info "PAGER" ~doc:"The pager used to consult the change log.";
-    Term.env_info "TERM" ~doc:"See option $(b,--no-pager)." ]
+  [ Cmd.Env.info "EDITOR" ~doc:"The editor used to edit the change log.";
+    Cmd.Env.info "PAGER" ~doc:"The pager used to consult the change log.";
+    Cmd.Env.info "TERM" ~doc:"See option $(b,--no-pager)." ]
 
 let man_xrefs = [ `Main; `Cmd "publish"; `Cmd "tag"; `Cmd "opam"; ]
 let man =
@@ -122,22 +121,6 @@ etc.";
                         VCS.") ]
 
 let cmd =
-  Term.(pure log $ Cli.setup $ Cli.pkg_file $ Cli.change_log $ action $
-        last $ last_version $ no_pager),
-  Term.info "log" ~doc ~sdocs ~exits ~envs ~man
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
+  Cmd.v (Cmd.info "log" ~doc ~sdocs ~exits ~envs ~man) @@
+  Term.(const log $ Cli.setup $ Cli.pkg_file $ Cli.change_log $ action $
+        last $ last_version $ no_pager)
