@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Bos_setup
@@ -26,7 +25,7 @@ let exec_match exec p =
 let find_exec exec dir =
   let ambiguous l =
     R.error_msgf "Ambiguous matches for %a, could match any of %a"
-      pp_exec exec Fmt.(list ~sep:(unit ", ") Fpath.pp) l
+      pp_exec exec Fmt.(list ~sep:(any ", ") Fpath.pp) l
   in
   OS.Dir.exists dir >>= function
   | false -> R.error_msgf "Build directory %a does not exist" Fpath.pp dir
@@ -87,7 +86,7 @@ let exec =
 
 let doc = "Run built executables"
 let sdocs = Manpage.s_common_options
-let exits = Term.exit_info 1 ~doc:"on run non-zero status exit." :: Cli.exits
+let exits = Cmd.Exit.info 1 ~doc:"on run non-zero status exit." :: Cli.exits
 let man_xrefs = [ `Main ]
 let man =
   [ `S Manpage.s_synopsis;
@@ -100,21 +99,5 @@ let man =
         in the future." ]
 
 let cmd =
-  Term.(pure run $ Cli.setup $ Cli.pkg_file $ Cli.build_dir $ exec $ args),
-  Term.info "run" ~doc ~sdocs ~exits ~man ~man_xrefs
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
+  Cmd.v (Cmd.info "run" ~doc ~sdocs ~exits ~man ~man_xrefs) @@
+  Term.(const run $ Cli.setup $ Cli.pkg_file $ Cli.build_dir $ exec $ args)
