@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Topkg_result
@@ -307,6 +306,7 @@ let clean p os =
   let file = install_file p in
   let build_dir = build_dir p in
   Topkg_os.File.delete file
+  >>= fun () -> Topkg_os.File.delete "pkg.itarget"
   >>= fun () -> (Topkg_build.clean p.build) os ~build_dir
   >>= fun () -> Ok 0
 
@@ -323,19 +323,3 @@ let lint_metas p =
 
 let lint_opams p =
   List.map (fun ((p, _), lint, lint_deps) -> (p, lint, lint_deps)) p.opams
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
